==> toycars-0.2.5.tar.gz: toycars-0.2.5/src/PlayerBomb.cpp <==
/*
	Copyright (C) 2005 by Ruben Zilibowitz <rzilibowitz@users.sourceforge.net>
	Part of the Toy Cars Project http://toycars.sourceforge.net

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License.
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY.

	See the COPYING file for more details.
*/

/*
 *  Created by Ruben Zilibowitz on 14/02/05.
 */

#include "PlayerBomb.h"
#include "SDL.h"
#include "SDL_image.h"
#include "ScException.h"
#include "Kaboom.h"
#include "CarGame.h"
#include "Player.h"

const char kBombImageFile[] = "images/bombsprite.png";
const int kBombFrameWidth = 64;
const int kBombFrameHeight = 64;
const ScRect kBombImageBounds = {0, 0, kBombFrameWidth, kBombFrameHeight};

PlayerBomb::PlayerBomb(double inFuse, Player* inFollowPlayer, CarGame *inGame, ScAnimation *inAnimation)
	: ScSprite(kBombImageBounds), fuse(inFuse), followPlayer(inFollowPlayer), game(inGame), animation(inAnimation)
{
	SDL_Surface* imgSurface;
	ScPixelData pixelData;
	
	// this is a master sprite
	isMaster = true;

	// create image surface
	imgSurface = IMG_Load(kBombImageFile);
	if(!imgSurface)
	{
		ScThrowErr("Could not load image file");
	}
	
	// setup the pixel data struct
	pixelData.pitch = imgSurface->pitch;
	pixelData.bytes_pp = imgSurface->format->BytesPerPixel;
	pixelData.internalformat = GL_RGBA;
	pixelData.width = imgSurface->w;
	pixelData.height = imgSurface->h;
	pixelData.format = GL_RGBA;
	pixelData.type = GL_UNSIGNED_BYTE;
	pixelData.pixels = (const char*)(imgSurface->pixels);
		
	// load the sprite frames
	load(kBombFrameWidth, kBombFrameHeight, 0, pixelData);
	
	// free the image surface
	SDL_FreeSurface(imgSurface);
}

void PlayerBomb::process(double dt)
{
	curFrame = (unsigned short)(0.5*(sin(800.0/(fuse + 6.0)) + 1.0)*numFrames) % numFrames;
	
	fuse -= dt;
	
	// if a follow panel is set, then follow it
	if (followPlayer)
	{
		centreAt(	0.5*(followPlayer->car.getBounds().right + followPlayer->car.getBounds().left),
					0.5*(followPlayer->car.getBounds().top + followPlayer->car.getBounds().bottom));
	}
	
	// if fuse has run out create an explosion and detonate player
	if (fuse < 0.0)
	{
        animation->push_back(new Kaboom(
			0.5*(bounds.right + bounds.left),
			0.5*(bounds.top + bounds.bottom), 10.0, animation));
		game->detonate(followPlayer);
        animation->scheduleRemove(this);
        //animation->remove(this);
        //delete this;
	}
}

==> toycars-0.3.0.tar.gz: toycars-0.3.0/src/PlayerBomb.cpp <==
/*
	Copyright (C) 2005 by Ruben Zilibowitz <rzilibowitz@users.sourceforge.net>
	Part of the Toy Cars Project http://toycars.sourceforge.net

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License.
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY.

	See the COPYING file for more details.
*/

/*
 *  Created by Ruben Zilibowitz on 14/02/05.
 */

#include "PlayerBomb.h"
#include "SDL.h"
#include "SDL_image.h"
#include "ScException.h"
#include "Kaboom.h"
#include "HotPotatoGame.h"
#include "Player.h"

const char kBombImageFile[] = "images/bombsprite.png";
const int kBombFrameWidth = 64;
const int kBombFrameHeight = 64;
const ScRect kBombImageBounds = {0, 0, kBombFrameWidth, kBombFrameHeight};

PlayerBomb::PlayerBomb(double inFuse, Player* inFollowPlayer, HotPotatoGame *inGame, ScAnimation *inAnimation)
	: ScSprite(kBombImageBounds), fuse(inFuse), followPlayer(inFollowPlayer), game(inGame), animation(inAnimation)
{
	SDL_Surface* imgSurface;
	ScPixelData pixelData;
	
	// this is a master sprite
	isMaster = true;

	// create image surface
	imgSurface = IMG_Load(kBombImageFile);
	if(!imgSurface)
	{
		ScThrowErr("Could not load image file");
	}
	
	// setup the pixel data struct
	pixelData.pitch = imgSurface->pitch;
	pixelData.bytes_pp = imgSurface->format->BytesPerPixel;
	pixelData.internalformat = GL_RGBA;
	pixelData.width = imgSurface->w;
	pixelData.height = imgSurface->h;
	pixelData.format = GL_RGBA;
	pixelData.type = GL_UNSIGNED_BYTE;
	pixelData.pixels = (const char*)(imgSurface->pixels);
		
	// load the sprite frames
	load(kBombFrameWidth, kBombFrameHeight, 0, pixelData);
	
	// free the image surface
	SDL_FreeSurface(imgSurface);
}

void PlayerBomb::process(double dt)
{
	curFrame = (unsigned short)(0.5*(sin(800.0/(fuse + 6.0)) + 1.0)*numFrames) % numFrames;
	
	fuse -= dt;
	
	// if a follow panel is set, then follow it
	if (followPlayer)
	{
		centreAt(	0.5*(followPlayer->car.getBounds().right + followPlayer->car.getBounds().left),
					0.5*(followPlayer->car.getBounds().top + followPlayer->car.getBounds().bottom));
	}
	
	// if fuse has run out create an explosion and detonate player
	if (fuse < 0.0)
	{
        animation->push_back(new Kaboom(
			0.5*(bounds.right + bounds.left),
			0.5*(bounds.top + bounds.bottom), 10.0, animation));
		game->detonate(followPlayer);
        animation->scheduleRemove(this);
        //animation->remove(this);
        //delete this;
	}
}
